[Libreoffice-commits] core.git: config_host.mk.in configure.ac cppuhelper/source jvmfwk/source ure/Package_install.mk

Tor Lillqvist tml at collabora.com
Sat Oct 5 11:11:26 PDT 2013


 config_host.mk.in           |    1 +
 configure.ac                |    9 +++++----
 cppuhelper/source/paths.cxx |   18 ++++++++++--------
 jvmfwk/source/fwkutil.hxx   |    4 +++-
 ure/Package_install.mk      |    2 +-
 5 files changed, 20 insertions(+), 14 deletions(-)

New commits:
commit 01e1a2465ef3e7658b749893d518e4720e04c40b
Author: Tor Lillqvist <tml at collabora.com>
Date:   Sat Oct 5 20:28:40 2013 +0300

    URE folder path fixes for the HAVE_FEATURE_MACOSX_MACLIKE_APP_STRUCTURE case
    
    Change-Id: I5019cce2172db7b3ac74e25f5ea9dc62e9fd03f8

diff --git a/config_host.mk.in b/config_host.mk.in
index c25addb..deb3e2f 100644
--- a/config_host.mk.in
+++ b/config_host.mk.in
@@ -320,6 +320,7 @@ export LIBO_SHARE_JAVA_FOLDER=@LIBO_SHARE_JAVA_FOLDER@
 export LIBO_SHARE_PRESETS_FOLDER=@LIBO_SHARE_PRESETS_FOLDER@
 export LIBO_SHARE_RESOURCE_FOLDER=@LIBO_SHARE_RESOURCE_FOLDER@
 export LIBO_URE_BIN_FOLDER=@LIBO_URE_BIN_FOLDER@
+export LIBO_URE_ETC_FOLDER=@LIBO_URE_ETC_FOLDER@
 export LIBO_URE_LIB_FOLDER=@LIBO_URE_LIB_FOLDER@
 export LIBO_URE_LIB_FOLDER_FOR_BUILD=@LIBO_URE_LIB_FOLDER_FOR_BUILD@
 export LIBO_URE_SHARE_FOLDER=@LIBO_URE_SHARE_FOLDER@
diff --git a/configure.ac b/configure.ac
index 1cd7c02..655b0e5 100644
--- a/configure.ac
+++ b/configure.ac
@@ -2977,9 +2977,9 @@ if test $_os = Darwin -a "$enable_canonical_installation_tree_structure" = yes;
     LIBO_SHARE_RESOURCE_FOLDER=Resources/resource
     LIBO_SHARE_SHELL_FOLDER=Resources/shell
     LIBO_URE_BIN_FOLDER=MacOS
-    LIBO_URE_ETC_FOLDER=Resources
+    LIBO_URE_ETC_FOLDER=Resources/ure/etc
     LIBO_URE_LIB_FOLDER=Frameworks
-    LIBO_URE_SHARE_FOLDER=Resources/ure
+    LIBO_URE_SHARE_FOLDER=Resources/ure/share
     LIBO_URE_SHARE_JAVA_FOLDER=Resources/java
     ENABLE_MACOSX_MACLIKE_APP_STRUCTURE=TRUE
     AC_DEFINE(HAVE_FEATURE_MACOSX_MACLIKE_APP_STRUCTURE)
@@ -2996,7 +2996,7 @@ elif test $_os = Darwin; then
     LIBO_SHARE_RESOURCE_FOLDER=MacOS/resource
     LIBO_SHARE_SHELL_FOLDER=MacOS/shell
     LIBO_URE_BIN_FOLDER=ure-link/bin
-    LIBO_URE_ETC_FOLDER=ure-link/bin
+    LIBO_URE_ETC_FOLDER=ure-link/lib
     LIBO_URE_LIB_FOLDER=ure-link/lib
     LIBO_URE_SHARE_FOLDER=ure-link/share
     LIBO_URE_SHARE_JAVA_FOLDER=ure-link/share/java
@@ -3030,7 +3030,7 @@ else
     LIBO_SHARE_RESOURCE_FOLDER=program/resource
     LIBO_SHARE_SHELL_FOLDER=program/shell
     LIBO_URE_BIN_FOLDER=ure/bin
-    LIBO_URE_ETC_FOLDER=ure/bin
+    LIBO_URE_ETC_FOLDER=ure/lib
     LIBO_URE_LIB_FOLDER=ure/lib
     LIBO_URE_SHARE_FOLDER=ure/share
     LIBO_URE_SHARE_JAVA_FOLDER=ure/share/java
@@ -3063,6 +3063,7 @@ AC_SUBST(LIBO_SHARE_JAVA_FOLDER)
 AC_SUBST(LIBO_SHARE_PRESETS_FOLDER)
 AC_SUBST(LIBO_SHARE_RESOURCE_FOLDER)
 AC_SUBST(LIBO_URE_BIN_FOLDER)
+AC_SUBST(LIBO_URE_ETC_FOLDER)
 AC_SUBST(LIBO_URE_LIB_FOLDER)
 AC_SUBST(LIBO_URE_SHARE_FOLDER)
 AC_SUBST(LIBO_URE_SHARE_JAVA_FOLDER)
diff --git a/jvmfwk/source/fwkutil.hxx b/jvmfwk/source/fwkutil.hxx
index 4c9ac04..66f438d 100644
--- a/jvmfwk/source/fwkutil.hxx
+++ b/jvmfwk/source/fwkutil.hxx
@@ -51,7 +51,9 @@ struct Bootstrap :
             OUStringBuffer buf(256);
             buf.append(getLibraryLocation());
 #if HAVE_FEATURE_MACOSX_MACLIKE_APP_STRUCTURE
-            buf.appendAscii( "/../" LIBO_ETC_FOLDER );
+            // For some reason the jvmfwk3rc file is traditionally in
+            // "ure/lib", i.e.  in LIBO_URE_ETC_FOLDER
+            buf.appendAscii( "/../" LIBO_URE_ETC_FOLDER );
 #endif
             buf.appendAscii(SAL_CONFIGFILE("/jvmfwk3"));
             OUString sIni = buf.makeStringAndClear();
diff --git a/ure/Package_install.mk b/ure/Package_install.mk
index 53a97f5..38b3240 100644
--- a/ure/Package_install.mk
+++ b/ure/Package_install.mk
@@ -28,7 +28,7 @@ else
 $(eval $(call gb_Package_add_symbolic_link,ure_install,ure-link,ure))
 endif
 
-$(eval $(call gb_Package_add_files,ure_install,$(LIBO_URE_LIB_FOLDER),\
+$(eval $(call gb_Package_add_files,ure_install,$(LIBO_URE_ETC_FOLDER),\
 	$(call gb_Helper_get_rcfile,jvmfwk3) \
 	$(call gb_Helper_get_rcfile,uno) \
 ))


More information about the Libreoffice-commits mailing list
diff --git a/cppuhelper/source/paths.cxx b/cppuhelper/source/paths.cxx
index ab54107..41abeb4 100644
--- a/cppuhelper/source/paths.cxx
+++ b/cppuhelper/source/paths.cxx
@@ -18,6 +18,7 @@
  */
 
 #include <config_features.h>
+#include <config_folders.h>
 
 #include "sal/config.h"
 
@@ -72,15 +73,16 @@ rtl::OUString cppu::getUnoIniUri() {
 #else
     rtl::OUString uri(get_this_libpath());
 #if HAVE_FEATURE_MACOSX_MACLIKE_APP_STRUCTURE
-    // We keep both the LO and URE dylibs direcly in the Frameworks
-    // folder and rc files in Resources. Except for unorc, of which
-    // there are two, the "LO" one (which is in Resources) and the
-    // "URE" one which is in Resources/ure. As this code goes into the
-    // cppuhelper library which is part of URE, we are looking for the
-    // latter one here. I think...
-    if (uri.endsWith( "/Frameworks" ) )
+    // We keep both the LO and URE dylibs direcly in "Frameworks"
+    // (that is, LIBO_LIB_FOLDER) and rc files in "Resources"
+    // (LIBO_ETC_FOLDER). Except for unorc, of which there are two,
+    // the "LO" one (which is in "Resources") and the "URE" one (which
+    // is in "Resources/ure/etc" (LIBO_URE_ETC_FOLDER)). As this code
+    // goes into the cppuhelper library which is part of URE, we are
+    // looking for the latter one here. I think...
+    if (uri.endsWith( "/" LIBO_LIB_FOLDER ) )
     {
-        uri = uri.copy( 0, uri.getLength() - (sizeof("Frameworks")-1) ) + "Resources/ure";
+        uri = uri.copy( 0, uri.getLength() - (sizeof(LIBO_LIB_FOLDER)-1) ) + LIBO_URE_ETC_FOLDER;
     }
 #endif
 #endif